<template>
	<view class="page-calendar-list">
		<view class="container" v-if="calendarLst.length > 0">
			<view class="uni-panel-content">
				<view v-for="(item,index) in calendarLst" class="uni-panel-calendar-item" :key="item.ID"
					@click="clickCalendarItem(item)">
					<view class="uni-panel-item">
						<text class="uni-panel-item-ico fs-calendar"></text>
						<text class="uni-panel-item-text blue-text">{{item.CreatorName}}</text>
						<text class="uni-panel-item-text">{{item.Name}}</text>
					</view>
					<text class="uni-panel-right-icon blue-text "
						:class="item.checked ? 'fs-CheckBoxOk2' : 'fs-CheckBoxEmpty2'" style="transform:scale(0.8)" />
				</view>
			</view>
			<view class="uni-panel-bottom">
				<view class="button-clz">
					<button class="uni-panel-button" @click="onOK">确定</button>
				</view>
			</view>
			<view class="uni-panel-safe-bottom" :style="{height:safeAreaBottom + 'px'}" />
		</view>
		<view class="container justify-center items-center" v-else>
			<view class="uni-panel-no-calendar">
				<view class="uni-no-calendar-tip">{{noCalendarTip}}</view>
			</view>
		</view>
	</view>
</template>

<script>
	import Session from "@/common/utils.js"
	import {
		otherList as calendarOtherList,
		subordinateList as calendarSubordinateList,
		publishList as calendarPublishList,
	} from "@/api/gungho/calendar.js"
	import {
		showModal,
		showToast,
		showLoading,
		hideLoading
	} from "@/common/Page.js"
	export default {
		name: "pageCalendarList",
		data() {
			return {
				safeAreaBottom: getApp().globalData.safeAreaBottom,
				options: {},
				calendarLst: [],
				noCalendarTip: "",
			}
		},
		methods: {
			setData: function(obj) {
				let that = this;
				let keys = [];
				let val, data;

				Object.keys(obj).forEach(function(key) {
					keys = key.split(".");
					val = obj[key];
					data = that.$data;
					keys.forEach(function(key2, index) {
						if (index + 1 == keys.length) {
							that.$set(data, key2, val);
						} else {
							if (!data[key2]) {
								that.$set(data, key2, {});
							}
						}
						data = data[key2];
					});
				});
			},
			loadShareList() {
				var _this = this
				showLoading("加载中，请稍后...")
				calendarOtherList(0x02).then((res) => {
					const list = res || []
					if (list.length > 0) {
						_this.setData({
							calendarLst: list
						})
					} else
						_this.setData({
							calendarLst: [],
							noCalendarTip: "没有共享给我的日历"
						})
					hideLoading()
				}).catch((rej) => {
					hideLoading()
					_this.setData({
						calendarLst: [],
						noCalendarTip: "没有共享给我的日历"
					})
					console.log("shareList catch", rej)
				})

			},
			loadPublicList() {
				var _this = this
				showLoading("加载中，请稍后...")
				calendarPublishList().then((res) => {
						hideLoading()
					const list = res || []
					if (list.length > 0) {
						_this.setData({
							calendarLst: list
						})
					} else {
						_this.setData({
							calendarLst: [],
							noCalendarTip: "没有公开日历"
						})
					}
				
				}).catch((rej) => {
					hideLoading()
					_this.setData({
						calendarLst: [],
						noCalendarTip: "没有公开日历"
					})
					console.log("publicList catch", rej)
				})
			},
			loadSubordinateList() {
				var _this = this
				showLoading("加载中，请稍后...")
				calendarSubordinateList().then((res) => {
					const list = res || []
						hideLoading()
					if (list.length > 0) {
						_this.setData({
							calendarLst: list
						})
					} else
						_this.setData({
							calendarLst: [],
							noCalendarTip: "没有我的下属日历"
						})
				
				}).catch((rej) => {
					hideLoading()
					_this.setData({
						calendarLst: [],
						noCalendarTip: "没有我的下属日历"
					})
					console.log("getSubordinate catch", rej)
				})
			},
			clickCalendarItem(item) {
				item.checked = !item.checked

			},
			onOK() {
				const list = []
				for (let i = 0; i < this.calendarLst.length; i++) {
					let item = this.calendarLst[i]
					if (item.checked) {
						list.push(item)
					}
				}
				let pages = getCurrentPages();
				let prepage = pages[pages.length - 2];
				prepage.$vm[this.options.evalfunction](list)
				uni.navigateBack({
					delta: 1
				})

			},
			showError(ex) {
				let tip = typeof ex == 'string' ? ex : typeof ex.err_msg == 'string' ? ex.err_msg : typeof ex.errMsg ==
					'string' ? ex.errMsg : ""
				showModal(tip, "提示", false)
			},
		},
		onLoad(option) {
			if (!option.evalfunction)
				option.evalfunction = 'getBackList'
			this.options = option;
			// #ifdef MP-DINGTALK

			my.setNavigationBar({
				backgroundColor: "#007AFF",
				frontColor: "#ffffff"
			})
			// #endif
			if (option.type == 0) {
				uni.setNavigationBarTitle({
					title: "从共享给我的日历选"
				})
				this.loadShareList()
			} else if (option.type == 1) {
				uni.setNavigationBarTitle({
					title: "从我的下属日历选"
				})
				this.loadSubordinateList()

			} else if (option.type == 2) {
				uni.setNavigationBarTitle({
					title: "从所有公共日历选"
				})
				this.loadPublicList()
			}
		}
	}
</script>

<style lang="scss" scoped>
	@import "../../common/css/button.scss";

	page {
		background-color: #e5eaee;
		height: calc(100vh - 10px);
	}

	.page-calendar-list {

		width: 750rpx;
		height: 100vh;
		background-color: #e5eaee;

		.justify-center {
			justify-content: center;
		}

		.items-center {
			align-items: center
		}

		.container {
			display: flex;
			width: 100%;
			height: 100%;
			flex-direction: column;

			.uni-panel-content {
				display: flex;
				flex: 1;
				width: 100%;
				padding: 8px 0;
				overflow: auto;
				flex-direction: column;
				height: calc(100% - 64px);
			}

			.uni-panel-calendar-item {
				display: flex;
				flex-direction: row;
				width: calc(750rpx - 30px);
				margin: 5px 10px;
				background-color: white;
				border-radius: 8px;
				padding: 10px 5px;
			}

			.uni-panel-item {
				width: 100%;
				flex: 1;

				.uni-panel-item-ico {
					// display: flex;
					margin: 4px 8px 4px 4px;
					font-size: 16px;
					color: #333;
					line-height: 50rpx;
				}

				.uni-panel-item-text {
					// display: flex;
					margin: 4px 8px 4px 4px;
					font-size: 14px;
					line-height: 50rpx;
				}


			}

			.blue-text {
				color: #007aff;
			}

			.uni-panel-right-icon {
				height: 50rpx;
				padding: 0px 4px;
				line-height: 50rpx;
				font-size: 24px;
				text-align: right;
			}

			.button-clz {
				display: flex;
				width: 100%;
				flex-direction: row;
				font-size: 17px !important;
				margin-top: 8px;
				margin-bottom: 8px;
				border-radius: 0px;
			}

			.uni-panel-button {
				width: 100%;
				border-radius: 12px;
				margin: 5px 12px 16px;
				background-color: #00aaff;
				color: #fff;
			}

			.uni-panel-bottom {
				display: flex;
				justify-content: flex-end;
				align-items: flex-end;
				min-height: 20px;
				padding: 8px 12px;
				font-size: 14px;
			}

			.uni-panel-no-calendar {
				padding: 20px;
			}

			.unino-calendar-tip {
				color: #aaa;
				padding-bottom: 20px;
				font-size: 20px;
			}
		}
	}
</style>